@@ -11,12 +11,12 @@ class JpsClient(BaseClient):
     def __init__(self, api_client: ApiClient):
         super().__init__(api_client)
 
-    def install_from_file(self, filename: str, env_name: str, settings: dict = None) -> str:
+    def install_from_file(self, filename: str, env_name: str = None, settings: dict = None) -> str:
         with open(filename) as file:
             manifest_content = file.read()
             return self.install(manifest_content, env_name, settings)
 
-    def install(self, manifest_content: str, env_name: str, settings: dict = None) -> str:
+    def install(self, manifest_content: str, env_name: str = None, settings: dict = None) -> str:
         response = self._execute(
             who_am_i(),
             jps=manifest_content,
